OC.L10N.register(
    "comments",
    {
    "Type in a new comment..." : "Neuer Kommentar...",
    "Delete comment" : "Kommentar löschen",
    "Post" : "Speichern",
    "Cancel" : "Abbrechen",
    "Edit comment" : "Kommentar bearbeiten",
    "[Deleted user]" : "[gelöschter Benutzer]",
    "Comments" : "Kommentare",
    "No other comments available" : "Keine anderen Kommentare verfügbar",
    "More comments..." : "Weitere Kommentare...",
    "Save" : "Speichern",
    "Allowed characters {count} of {max}" : "{count} von {max} Zeichen benutzt",
    "Error occurred while retrieving comment with id {id}" : "Es ist ein Fehler beim Empfangen des Kommentars mit der ID {id} aufgetreten",
    "Error occurred while updating comment with id {id}" : "Es ist ein Fehler beim Aktualisieren des Kommentars mit der ID {id} aufgetreten",
    "Error occurred while posting comment" : "Es ist ein Fehler beim Veröffentlichen des Kommentars aufgetreten",
    "{count} unread comments" : "[count] ungelesene Kommentare",
    "Comment" : "Kommentar",
    "<strong>Comments</strong> for files <em>(always listed in stream)</em>" : "<strong>Kommentare</strong> für Dateien<em>(immer im Stream aufgelistet)</em>",
    "You commented" : "Durch dich kommentiert",
    "%1$s commented" : "%1$s kommentiert",
    "You commented on %2$s" : "Sie haben %2$s kommentiert",
    "%1$s commented on %2$s" : "%1$s kommentierte %2$s"
},
"nplurals=2; plural=(n != 1);");
